@@ -1,6 +1,8 @@
 from .worker import ValiotWorker
+from .worker import QueueType, JobStatus, PollingMode
+from .uploaders import update_job
 
 # * Package name:
 name = 'ValiotWorker'
 # * required here for pypi upload exceptions:
-__version__ = "0.4.0"
+__version__ = "1.0.0"
