@@ -10,6 +10,7 @@ query WorkerJobs($worker: String){
         id
         userId
         input
+        context
         output
         progress
         jobStatus
@@ -21,6 +22,13 @@ query WorkerJobs($worker: String){
           enabled
           schedule
           query
+          lockRequired
+          # locks(orderBy:{desc:ID} limit: 1){
+            # id
+            # active
+            # startAt
+            # endAt
+          # }
         }
     }
 }
@@ -105,6 +113,13 @@ all_queues = '''
     schedule
     query
     lastRunAt
+    lockRequired
+    locks(orderBy:{ desc:ID } limit: 1){
+      id
+      active
+      startAt
+      endAt
+    }
     updatedAt
     insertedAt
   }
